@@ -138,6 +138,14 @@ fn test_db_tt() {
     assert!(expanded_url.unwrap().starts_with("https://www.dropbox.com/"));
 }
 
+#[test]
+fn test_f_ls() {
+    let url = "https://f.ls/jdsku";
+    let expanded_url = unshorten(url, None);
+    assert!(expanded_url.is_some());
+    assert_eq!(expanded_url, Some("https://www.google.com/".to_string()));
+}
+
 #[test]
 fn test_fb_me() {
     let url = "https://fb.me/mashable";
@@ -284,6 +292,14 @@ fn test_ow_ly() {
     assert_eq!(expanded_url, Some("http://t.co/cAcQV4QTOS".to_string()));
 }
 
+#[test]
+fn test_plu_sh() {
+    let url = "https://plu.sh/xnwb8";
+    let expanded_url = unshorten(url, None);
+    assert!(expanded_url.is_some());
+    assert_eq!(expanded_url, Some("https://www.google.com/".to_string()));
+}
+
 #[test]
 fn test_q_gs() {
     let url = "http://q.gs/FNOHk";
@@ -372,6 +388,14 @@ fn test_smc_sg() {
     assert!(expanded_url.unwrap().starts_with("https://google.com/"));
 }
 
+#[test]
+fn test_snip_ly() {
+    let url = "snip.ly/soyummy-cookbook";
+    let expanded_url = unshorten(url, None);
+    assert!(expanded_url.is_some());
+    assert!(expanded_url.unwrap().starts_with("https://www.soyummystore.com"));
+}
+
 #[test]
 fn test_t_co() {
     let url = "https://t.co/bYeHhy9kAU";
@@ -447,6 +471,14 @@ fn test_tr_im() {
     assert!(expanded_url.unwrap().starts_with("https://google.com/"));
 }
 
+#[test]
+fn test_trib_al() {
+    let url = "https://trib.al/YKNecc2";
+    let expanded_url = unshorten(url, None);
+    assert!(expanded_url.is_some());
+    assert!(expanded_url.unwrap().starts_with("https://mashable.com/article"));
+}
+
 #[test]
 fn test_u_to() {
     let url = "https://u.to/P05FGw";
@@ -479,6 +511,14 @@ fn test_vzturl_com() {
     assert!(expanded_url.unwrap().starts_with("https://www.amazon.com/Sabrent-Thunderbolt-"));
 }
 
+#[test]
+fn test_waa_ai() {
+    let url = "https://waa.ai/muZV";
+    let expanded_url = unshorten(url, None);
+    assert!(expanded_url.is_some());
+    assert!(expanded_url.unwrap().starts_with("https://www.google.com/search?q=rust"));
+}
+
 #[test]
 fn test_yourwish_es() {
     let url = "http://yourwish.es/oxgyc";
